@@ -62,29 +62,29 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "alloc_8h.html",
-"group__pw__client.html#gaf334e712707cd3d4fb97100f3baedeb0",
-"group__pw__global.html#ga5a70a0e4be433825f0e5baf7277c0e7e",
-"group__pw__keys.html#ga8226b0005fed53b77740e919947f6e60",
-"group__pw__module.html#gad670c8d581f68d016f475c12cff250c8",
-"group__pw__resource.html#gafc12935cd9ee93e992cae1e2910e6f04",
-"group__pw__utils.html#ga8869815cdd42998571019730afd248ff",
-"group__spa__cpu.html#ga863ee498bc3630a98ee12fe569a9dc30",
-"group__spa__interfaces.html#ga6492da0e834e92dbbcef7dd3026ce04f",
-"group__spa__names.html#ga4ca9373715177f903a0014796b1d8821",
-"group__spa__param.html#ga304470cf722efd8b2b0617268235c322",
-"group__spa__param.html#gga09c0ecc808ca333e1dd8a994b8809586add5a25402d5f44adde274c95091135d2",
-"group__spa__param.html#gga741ca54fc7f93308779660120bbed31eaa5d835e17315a1ed31a73323da1fa02a",
-"group__spa__param.html#ggad7758d1c91573ef57ebf61ac113bb43ea43dce82d44b02558ba417caccf9395da",
-"group__spa__pod.html#ga9382aceb62c82555c3e3223fa0da4d16",
-"group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a6b256812f3b819d23d240f76d70e2dbf",
-"page_midi.html#autotoc_md21",
-"page_spa_plugins.html#autotoc_md234",
-"structpw__core__events.html#a8a700a03453729d52d96112647125303",
-"structpw__link__info.html#a5a21130d91e20dafc4ce1b09b7c30aca",
-"structpw__time.html#ad817da21bea1591d70f837c251a73468",
-"structspa__graph__node.html#ada29bc9109cd890c74cfba630989b76c",
-"structspa__node__methods.html#a788f398e8fa5e85f03ecb68602821204",
-"structspa__video__info__dsp.html#ada698c22ed974fa690ff6ee37855e659"
+"group__pw__client.html#gae9c05c6686aa7db3f69466363e7b8077",
+"group__pw__global.html#ga37767f3d8d027ae10433a0801cab0dda",
+"group__pw__keys.html#ga7e12dd6c9dec4a345c8a2a62f138b5bf",
+"group__pw__module.html#ga8c4bfe6ad4da2e2443ba7985ae7527cb",
+"group__pw__resource.html#ga61e286d92a2f528ebe48cb1436ac4eba",
+"group__pw__thread__loop.html#gacb9c26a513d752803fd272a4ea2bc891",
+"group__spa__cpu.html#ga36f54e2aac3837cb3631db07cbfde3e2",
+"group__spa__hooks.html#gacbc74f9ceab3dc7c5d6d8c3eca6a41e5",
+"group__spa__names.html#ga0847db019357b78b2fda5d40da8f2d39",
+"group__spa__param.html#ga1b344a251727332372451ba66b0c8162",
+"group__spa__param.html#gga09c0ecc808ca333e1dd8a994b8809586aa95628ab8f3e1d11150be7c7964d36df",
+"group__spa__param.html#gga6fa558a42ebf277d0fe21e1bee5c1218ac7f8797af31fc4ac37d4ad72fe80a92c",
+"group__spa__param.html#ggad7758d1c91573ef57ebf61ac113bb43ea107b70d9ca312a61fa29c3daecc91cb8",
+"group__spa__pod.html#ga85016b1c73cf76d8c4789a6f539ac4ec",
+"group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a1195438b5c43f33a3fe50accde463f9b",
+"page_library.html#autotoc_md62",
+"page_session_manager.html#autotoc_md66",
+"structpw__context__events.html#a8b2b69a9c179e37c9185929535a047f0",
+"structpw__impl__port__events.html",
+"structpw__stream__events.html#a1de8432b45484bc0e060162b78720c02",
+"structspa__fraction.html",
+"structspa__node__events.html#a37b6ed18688f456b4c4e9b157879414f",
+"structspa__thread__utils__methods.html#ab1126024161570f88d077ecee01066e8"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
